# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.11.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.models.manifest_extension_command import ManifestExtensionCommand

class TestManifestExtensionCommand(unittest.TestCase):
    """ManifestExtensionCommand unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ManifestExtensionCommand:
        """Test ManifestExtensionCommand
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ManifestExtensionCommand`
        """
        model = ManifestExtensionCommand()
        if include_optional:
            return ManifestExtensionCommand(
                id = 'convert',
                on = picteus_ws_client.models.manifest_extension_command_on.ManifestExtensionCommandOn(
                    entity = null, 
                    with_tags = [
                        '0'
                        ], ),
                parameters = None,
                specifications = [
                    picteus_ws_client.models.manifest_extension_command_specification.ManifestExtensionCommandSpecification(
                        locale = 'en', 
                        label = 'Resize an image', 
                        description = 'Resizes an image given a format asked to the user.', )
                    ]
            )
        else:
            return ManifestExtensionCommand(
                id = 'convert',
                on = picteus_ws_client.models.manifest_extension_command_on.ManifestExtensionCommandOn(
                    entity = null, 
                    with_tags = [
                        '0'
                        ], ),
                specifications = [
                    picteus_ws_client.models.manifest_extension_command_specification.ManifestExtensionCommandSpecification(
                        locale = 'en', 
                        label = 'Resize an image', 
                        description = 'Resizes an image given a format asked to the user.', )
                    ],
        )
        """

    def testManifestExtensionCommand(self):
        """Test ManifestExtensionCommand"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.11.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.models.search_parameters import SearchParameters

class TestSearchParameters(unittest.TestCase):
    """SearchParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SearchParameters:
        """Test SearchParameters
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SearchParameters`
        """
        model = SearchParameters()
        if include_optional:
            return SearchParameters(
                filter = picteus_ws_client.models.search_filter.SearchFilter(
                    criteria = null, 
                    origin = null, 
                    sorting = null, ),
                collection_id = 123,
                range = picteus_ws_client.models.search_range.SearchRange(
                    take = 20, 
                    skip = 0, )
            )
        else:
            return SearchParameters(
        )
        """

    def testSearchParameters(self):
        """Test SearchParameters"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.11.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from picteus_ws_client.models.image_format import ImageFormat
from picteus_ws_client.models.search_features import SearchFeatures
from picteus_ws_client.models.search_keyword import SearchKeyword
from picteus_ws_client.models.search_properties import SearchProperties
from picteus_ws_client.models.search_tags import SearchTags
from typing import Optional, Set
from typing_extensions import Self

class SearchCriteria(BaseModel):
    """
    Criteria when searching for images
    """ # noqa: E501
    formats: Optional[List[ImageFormat]] = Field(default=None, description="A filter used by the search which will limit the result entities to those having one of the provided image formats")
    keyword: Optional[SearchKeyword] = Field(default=None, description="A filter which limits the result entities with the provided text specifications")
    tags: Optional[SearchTags] = Field(default=None, description="A filter which limits the result entities with the provided tags specifications")
    features: Optional[SearchFeatures] = Field(default=None, description="A filter which limits the result entities with the provided features specifications")
    properties: Optional[SearchProperties] = Field(default=None, description="A filter which limits the result entities with the provided technical properties")
    __properties: ClassVar[List[str]] = ["formats", "keyword", "tags", "features", "properties"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SearchCriteria from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of keyword
        if self.keyword:
            _dict['keyword'] = self.keyword.to_dict()
        # override the default output from pydantic by calling `to_dict()` of tags
        if self.tags:
            _dict['tags'] = self.tags.to_dict()
        # override the default output from pydantic by calling `to_dict()` of features
        if self.features:
            _dict['features'] = self.features.to_dict()
        # override the default output from pydantic by calling `to_dict()` of properties
        if self.properties:
            _dict['properties'] = self.properties.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SearchCriteria from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "formats": obj.get("formats"),
            "keyword": SearchKeyword.from_dict(obj["keyword"]) if obj.get("keyword") is not None else None,
            "tags": SearchTags.from_dict(obj["tags"]) if obj.get("tags") is not None else None,
            "features": SearchFeatures.from_dict(obj["features"]) if obj.get("features") is not None else None,
            "properties": SearchProperties.from_dict(obj["properties"]) if obj.get("properties") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.11.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from picteus_ws_client.models.manifest_instructions import ManifestInstructions
from picteus_ws_client.models.manifest_runtime import ManifestRuntime
from picteus_ws_client.models.manifest_user_interface import ManifestUserInterface
from typing import Optional, Set
from typing_extensions import Self

class Manifest(BaseModel):
    """
    The manifest of an extension
    """ # noqa: E501
    id: Annotated[str, Field(min_length=1, strict=True, max_length=32)] = Field(description="The identifier of the extension")
    version: Annotated[str, Field(min_length=5, strict=True, max_length=32)] = Field(description="The version of the extension, which should follow the semver convention")
    name: Annotated[str, Field(min_length=1, strict=True, max_length=128)] = Field(description="The name of the extension")
    description: Annotated[str, Field(min_length=1, strict=True, max_length=1024)] = Field(description="The description of the extension's purpose")
    runtimes: List[ManifestRuntime] = Field(description="The required runtime environments")
    instructions: Annotated[List[ManifestInstructions], Field(min_length=1)] = Field(description="The instructions regarding the way the extension handle events")
    settings: Dict[str, Any] = Field(description="The extension settings definition")
    ui: Optional[ManifestUserInterface] = Field(default=None, description="The User Interface definition of the extensions")
    __properties: ClassVar[List[str]] = ["id", "version", "name", "description", "runtimes", "instructions", "settings", "ui"]

    @field_validator('id')
    def id_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[a-z0-9A-Z-_.]{1,32}$", value):
            raise ValueError(r"must validate the regular expression /^[a-z0-9A-Z-_.]{1,32}$/")
        return value

    @field_validator('version')
    def version_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^(0|[1-9]\d*)\.(0|[1-9]\d*)\.(0|[1-9]\d*)(?:-((?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*)(?:\.(?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*))*))?(?:\+([0-9a-zA-Z-]+(?:\.[0-9a-zA-Z-]+)*))?$", value):
            raise ValueError(r"must validate the regular expression /^(0|[1-9]\d*)\.(0|[1-9]\d*)\.(0|[1-9]\d*)(?:-((?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*)(?:\.(?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*))*))?(?:\+([0-9a-zA-Z-]+(?:\.[0-9a-zA-Z-]+)*))?$/")
        return value

    @field_validator('name')
    def name_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[a-z0-9A-Z-_. ]{1,128}$", value):
            raise ValueError(r"must validate the regular expression /^[a-z0-9A-Z-_. ]{1,128}$/")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Manifest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in runtimes (list)
        _items = []
        if self.runtimes:
            for _item_runtimes in self.runtimes:
                if _item_runtimes:
                    _items.append(_item_runtimes.to_dict())
            _dict['runtimes'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in instructions (list)
        _items = []
        if self.instructions:
            for _item_instructions in self.instructions:
                if _item_instructions:
                    _items.append(_item_instructions.to_dict())
            _dict['instructions'] = _items
        # override the default output from pydantic by calling `to_dict()` of ui
        if self.ui:
            _dict['ui'] = self.ui.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Manifest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "version": obj.get("version"),
            "name": obj.get("name"),
            "description": obj.get("description"),
            "runtimes": [ManifestRuntime.from_dict(_item) for _item in obj["runtimes"]] if obj.get("runtimes") is not None else None,
            "instructions": [ManifestInstructions.from_dict(_item) for _item in obj["instructions"]] if obj.get("instructions") is not None else None,
            "settings": obj.get("settings"),
            "ui": ManifestUserInterface.from_dict(obj["ui"]) if obj.get("ui") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.11.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ImageFeatureType(str, Enum):
    """
    All the possible types for an image feature.
    """

    """
    allowed enum values
    """
    CAPTION = 'caption'
    DESCRIPTION = 'description'
    COMMENT = 'comment'
    ANNOTATION = 'annotation'
    METADATA = 'metadata'
    RECIPE = 'recipe'
    IDENTITY = 'identity'
    OTHER = 'other'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ImageFeatureType from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.11.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.api.extension_api import ExtensionApi


class TestExtensionApi(unittest.TestCase):
    """ExtensionApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ExtensionApi()

    def tearDown(self) -> None:
        pass

    def test_extension_activities(self) -> None:
        """Test case for extension_activities

        Indicates the extension activities
        """
        pass

    def test_extension_build(self) -> None:
        """Test case for extension_build

        Builds an extension
        """
        pass

    def test_extension_generate(self) -> None:
        """Test case for extension_generate

        Generates an extension
        """
        pass

    def test_extension_get(self) -> None:
        """Test case for extension_get

        Gets an extension
        """
        pass

    def test_extension_get_configuration(self) -> None:
        """Test case for extension_get_configuration

        Provides the extensions configuration
        """
        pass

    def test_extension_get_settings(self) -> None:
        """Test case for extension_get_settings

        Gets an extension settings
        """
        pass

    def test_extension_install(self) -> None:
        """Test case for extension_install

        Installs an extension
        """
        pass

    def test_extension_install_chrome_extension(self) -> None:
        """Test case for extension_install_chrome_extension

        Installs a Chrome extension
        """
        pass

    def test_extension_list(self) -> None:
        """Test case for extension_list

        Lists all extensions
        """
        pass

    def test_extension_pause_or_resume(self) -> None:
        """Test case for extension_pause_or_resume

        Pauses or resumes an extension
        """
        pass

    def test_extension_run_image_command(self) -> None:
        """Test case for extension_run_image_command

        Runs a command exposed by an extension, on images
        """
        pass

    def test_extension_run_process_command(self) -> None:
        """Test case for extension_run_process_command

        Runs a command exposed by an extension, on the process
        """
        pass

    def test_extension_set_settings(self) -> None:
        """Test case for extension_set_settings

        Sets an extension settings
        """
        pass

    def test_extension_synchronize(self) -> None:
        """Test case for extension_synchronize

        Synchronizes the images via an extension
        """
        pass

    def test_extension_uninstall(self) -> None:
        """Test case for extension_uninstall

        Uninstalls an extension
        """
        pass

    def test_extension_update(self) -> None:
        """Test case for extension_update

        Updates an extension
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.11.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ManifestEvent(str, Enum):
    """
    The events which will trigger the instructions
    """

    """
    allowed enum values
    """
    PROCESS_DOT_STARTED = 'process.started'
    PROCESS_DOT_RUN_COMMAND = 'process.runCommand'
    EXTENSION_DOT_SETTINGS = 'extension.settings'
    IMAGE_DOT_CREATED = 'image.created'
    IMAGE_DOT_UPDATED = 'image.updated'
    IMAGE_DOT_DELETED = 'image.deleted'
    IMAGE_DOT_COMPUTE_FEATURES = 'image.computeFeatures'
    IMAGE_DOT_COMPUTE_EMBEDDINGS = 'image.computeEmbeddings'
    IMAGE_DOT_COMPUTE_TAGS = 'image.computeTags'
    IMAGE_DOT_RUN_COMMAND = 'image.runCommand'
    TEXT_DOT_COMPUTE_EMBEDDINGS = 'text.computeEmbeddings'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ManifestEvent from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.11.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.models.api_secret import ApiSecret

class TestApiSecret(unittest.TestCase):
    """ApiSecret unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiSecret:
        """Test ApiSecret
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiSecret`
        """
        model = ApiSecret()
        if include_optional:
            return ApiSecret(
                id = 123,
                creation_date = 1761384334302,
                name = 'My entity name',
                comment = 'My comment on the entity',
                type = 'key',
                expiration_date = 1761385316688,
                scope = 'image:read,repository:read',
                value = 'Z&Q78&fqkPq'
            )
        else:
            return ApiSecret(
                id = 123,
                creation_date = 1761384334302,
                name = 'My entity name',
                type = 'key',
                value = 'Z&Q78&fqkPq',
        )
        """

    def testApiSecret(self):
        """Test ApiSecret"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.11.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from picteus_ws_client.models.api_secret import ApiSecret
from picteus_ws_client.models.api_secret_summary import ApiSecretSummary
from picteus_ws_client.models.api_secret_type import ApiSecretType
from picteus_ws_client.models.application_metadata import ApplicationMetadata
from picteus_ws_client.models.application_metadata_item import ApplicationMetadataItem
from picteus_ws_client.models.application_metadata_item_value import ApplicationMetadataItemValue
from picteus_ws_client.models.collection import Collection
from picteus_ws_client.models.command_entity import CommandEntity
from picteus_ws_client.models.computed_image_format import ComputedImageFormat
from picteus_ws_client.models.configuration_capability import ConfigurationCapability
from picteus_ws_client.models.configuration_extension_command import ConfigurationExtensionCommand
from picteus_ws_client.models.constants_registry import ConstantsRegistry
from picteus_ws_client.models.dates import Dates
from picteus_ws_client.models.extension import Extension
from picteus_ws_client.models.extension_activity import ExtensionActivity
from picteus_ws_client.models.extension_activity_kind import ExtensionActivityKind
from picteus_ws_client.models.extension_and_manual import ExtensionAndManual
from picteus_ws_client.models.extension_generation_options import ExtensionGenerationOptions
from picteus_ws_client.models.extension_image_embeddings import ExtensionImageEmbeddings
from picteus_ws_client.models.extension_image_feature import ExtensionImageFeature
from picteus_ws_client.models.extension_image_feature_name import ExtensionImageFeatureName
from picteus_ws_client.models.extension_image_features_attribute import ExtensionImageFeaturesAttribute
from picteus_ws_client.models.extension_image_tag import ExtensionImageTag
from picteus_ws_client.models.extension_image_tags_attribute import ExtensionImageTagsAttribute
from picteus_ws_client.models.extension_manual import ExtensionManual
from picteus_ws_client.models.extension_settings import ExtensionSettings
from picteus_ws_client.models.extension_status import ExtensionStatus
from picteus_ws_client.models.extensions_configuration import ExtensionsConfiguration
from picteus_ws_client.models.generation_recipe import GenerationRecipe
from picteus_ws_client.models.generation_recipe_prompt import GenerationRecipePrompt
from picteus_ws_client.models.image import Image
from picteus_ws_client.models.image_dimensions import ImageDimensions
from picteus_ws_client.models.image_distance import ImageDistance
from picteus_ws_client.models.image_embeddings import ImageEmbeddings
from picteus_ws_client.models.image_feature import ImageFeature
from picteus_ws_client.models.image_feature_format import ImageFeatureFormat
from picteus_ws_client.models.image_feature_null_value import ImageFeatureNullValue
from picteus_ws_client.models.image_feature_type import ImageFeatureType
from picteus_ws_client.models.image_feature_value import ImageFeatureValue
from picteus_ws_client.models.image_format import ImageFormat
from picteus_ws_client.models.image_media_url import ImageMediaUrl
from picteus_ws_client.models.image_metadata import ImageMetadata
from picteus_ws_client.models.image_resize_render import ImageResizeRender
from picteus_ws_client.models.image_summary import ImageSummary
from picteus_ws_client.models.instructions_prompt import InstructionsPrompt
from picteus_ws_client.models.manifest import Manifest
from picteus_ws_client.models.manifest_capability import ManifestCapability
from picteus_ws_client.models.manifest_capability_id import ManifestCapabilityId
from picteus_ws_client.models.manifest_event import ManifestEvent
from picteus_ws_client.models.manifest_execution import ManifestExecution
from picteus_ws_client.models.manifest_extension_command import ManifestExtensionCommand
from picteus_ws_client.models.manifest_extension_command_on import ManifestExtensionCommandOn
from picteus_ws_client.models.manifest_extension_command_specification import ManifestExtensionCommandSpecification
from picteus_ws_client.models.manifest_instructions import ManifestInstructions
from picteus_ws_client.models.manifest_interface_element import ManifestInterfaceElement
from picteus_ws_client.models.manifest_runtime import ManifestRuntime
from picteus_ws_client.models.manifest_runtime_environment import ManifestRuntimeEnvironment
from picteus_ws_client.models.manifest_throttling_policy import ManifestThrottlingPolicy
from picteus_ws_client.models.manifest_user_interface import ManifestUserInterface
from picteus_ws_client.models.prompt_kind import PromptKind
from picteus_ws_client.models.repository import Repository
from picteus_ws_client.models.repository_activity import RepositoryActivity
from picteus_ws_client.models.repository_activity_kind import RepositoryActivityKind
from picteus_ws_client.models.repository_location_type import RepositoryLocationType
from picteus_ws_client.models.repository_status import RepositoryStatus
from picteus_ws_client.models.search_criteria import SearchCriteria
from picteus_ws_client.models.search_feature_comparison_operator import SearchFeatureComparisonOperator
from picteus_ws_client.models.search_feature_condition import SearchFeatureCondition
from picteus_ws_client.models.search_feature_condition_value import SearchFeatureConditionValue
from picteus_ws_client.models.search_feature_logical_operator import SearchFeatureLogicalOperator
from picteus_ws_client.models.search_features import SearchFeatures
from picteus_ws_client.models.search_features_result import SearchFeaturesResult
from picteus_ws_client.models.search_filter import SearchFilter
from picteus_ws_client.models.search_filter_origin import SearchFilterOrigin
from picteus_ws_client.models.search_image_result import SearchImageResult
from picteus_ws_client.models.search_image_summary_result import SearchImageSummaryResult
from picteus_ws_client.models.search_images_origin import SearchImagesOrigin
from picteus_ws_client.models.search_keyword import SearchKeyword
from picteus_ws_client.models.search_origin_nature import SearchOriginNature
from picteus_ws_client.models.search_parameters import SearchParameters
from picteus_ws_client.models.search_properties import SearchProperties
from picteus_ws_client.models.search_property_range import SearchPropertyRange
from picteus_ws_client.models.search_range import SearchRange
from picteus_ws_client.models.search_repositories_origin import SearchRepositoriesOrigin
from picteus_ws_client.models.search_sorting import SearchSorting
from picteus_ws_client.models.search_sorting_property import SearchSortingProperty
from picteus_ws_client.models.search_tags import SearchTags
from picteus_ws_client.models.search_tags_result import SearchTagsResult
from picteus_ws_client.models.settings import Settings
from picteus_ws_client.models.software import Software
from picteus_ws_client.models.textual_prompt import TextualPrompt
from picteus_ws_client.models.user_interface_anchor import UserInterfaceAnchor




# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.11.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.api.repository_api import RepositoryApi


class TestRepositoryApi(unittest.TestCase):
    """RepositoryApi unit test stubs"""

    def setUp(self) -> None:
        self.api = RepositoryApi()

    def tearDown(self) -> None:
        pass

    def test_repository_activities(self) -> None:
        """Test case for repository_activities

        Indicates the repositories activities
        """
        pass

    def test_repository_create(self) -> None:
        """Test case for repository_create

        Creates a repository
        """
        pass

    def test_repository_delete(self) -> None:
        """Test case for repository_delete

        Deletes a repository
        """
        pass

    def test_repository_ensure(self) -> None:
        """Test case for repository_ensure

        Ensures a repository exists
        """
        pass

    def test_repository_get(self) -> None:
        """Test case for repository_get

        Gets a repository
        """
        pass

    def test_repository_get_feature_names(self) -> None:
        """Test case for repository_get_feature_names

        Gets all the feature names
        """
        pass

    def test_repository_get_image_by_url(self) -> None:
        """Test case for repository_get_image_by_url

        Gets an image from its URL
        """
        pass

    def test_repository_get_tags(self) -> None:
        """Test case for repository_get_tags

        Gets all the tags
        """
        pass

    def test_repository_list(self) -> None:
        """Test case for repository_list

        Lists repositories
        """
        pass

    def test_repository_rename_image(self) -> None:
        """Test case for repository_rename_image

        Renames an image
        """
        pass

    def test_repository_start_or_stop(self) -> None:
        """Test case for repository_start_or_stop

        Starts or stop the repositories
        """
        pass

    def test_repository_store_image(self) -> None:
        """Test case for repository_store_image

        Creates an image in the repository
        """
        pass

    def test_repository_synchronize(self) -> None:
        """Test case for repository_synchronize

        Synchronizes a repository
        """
        pass

    def test_repository_watch(self) -> None:
        """Test case for repository_watch

        Starts or stops watching a repository
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.11.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.models.configuration_extension_command import ConfigurationExtensionCommand

class TestConfigurationExtensionCommand(unittest.TestCase):
    """ConfigurationExtensionCommand unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ConfigurationExtensionCommand:
        """Test ConfigurationExtensionCommand
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ConfigurationExtensionCommand`
        """
        model = ConfigurationExtensionCommand()
        if include_optional:
            return ConfigurationExtensionCommand(
                extension_id = 'extension-id',
                command = picteus_ws_client.models.manifest_extension_command.ManifestExtensionCommand(
                    id = 'convert', 
                    on = null, 
                    parameters = picteus_ws_client.models.parameters.parameters(), 
                    specifications = [
                        picteus_ws_client.models.manifest_extension_command_specification.ManifestExtensionCommandSpecification(
                            locale = 'en', 
                            label = 'Resize an image', 
                            description = 'Resizes an image given a format asked to the user.', )
                        ], )
            )
        else:
            return ConfigurationExtensionCommand(
                extension_id = 'extension-id',
                command = picteus_ws_client.models.manifest_extension_command.ManifestExtensionCommand(
                    id = 'convert', 
                    on = null, 
                    parameters = picteus_ws_client.models.parameters.parameters(), 
                    specifications = [
                        picteus_ws_client.models.manifest_extension_command_specification.ManifestExtensionCommandSpecification(
                            locale = 'en', 
                            label = 'Resize an image', 
                            description = 'Resizes an image given a format asked to the user.', )
                        ], ),
        )
        """

    def testConfigurationExtensionCommand(self):
        """Test ConfigurationExtensionCommand"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.11.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBytes, StrictStr, field_validator
from typing import Tuple, Union
from typing_extensions import Annotated

from picteus_ws_client.api_client import ApiClient, RequestSerialized
from picteus_ws_client.api_response import ApiResponse
from picteus_ws_client.rest import RESTResponseType


class ImageAttachmentApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def imageattachment_create(
        self,
        image_id: Annotated[str, Field(min_length=36, strict=True, max_length=36, description="The image identifier")],
        extension_id: Annotated[str, Field(min_length=1, strict=True, max_length=32, description="The extension identifier")],
        mime_type: Annotated[str, Field(min_length=1, strict=True, max_length=32, description="The MIME type of the attachment payload")],
        body: Annotated[Union[Annotated[bytes, Field(strict=True, max_length=1048576)], Annotated[str, Field(strict=True, max_length=1048576)], Tuple[str, Annotated[bytes, Field(strict=True, max_length=1048576)]]], Field(description="The attachment payload")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> str:
        """Declares an image binary attachment

        Stores a binary attachment related to an image for a given extension.

        :param image_id: The image identifier (required)
        :type image_id: str
        :param extension_id: The extension identifier (required)
        :type extension_id: str
        :param mime_type: The MIME type of the attachment payload (required)
        :type mime_type: str
        :param body: The attachment payload (required)
        :type body: bytearray
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._imageattachment_create_serialize(
            image_id=image_id,
            extension_id=extension_id,
            mime_type=mime_type,
            body=body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "str",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def imageattachment_create_with_http_info(
        self,
        image_id: Annotated[str, Field(min_length=36, strict=True, max_length=36, description="The image identifier")],
        extension_id: Annotated[str, Field(min_length=1, strict=True, max_length=32, description="The extension identifier")],
        mime_type: Annotated[str, Field(min_length=1, strict=True, max_length=32, description="The MIME type of the attachment payload")],
        body: Annotated[Union[Annotated[bytes, Field(strict=True, max_length=1048576)], Annotated[str, Field(strict=True, max_length=1048576)], Tuple[str, Annotated[bytes, Field(strict=True, max_length=1048576)]]], Field(description="The attachment payload")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[str]:
        """Declares an image binary attachment

        Stores a binary attachment related to an image for a given extension.

        :param image_id: The image identifier (required)
        :type image_id: str
        :param extension_id: The extension identifier (required)
        :type extension_id: str
        :param mime_type: The MIME type of the attachment payload (required)
        :type mime_type: str
        :param body: The attachment payload (required)
        :type body: bytearray
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._imageattachment_create_serialize(
            image_id=image_id,
            extension_id=extension_id,
            mime_type=mime_type,
            body=body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "str",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def imageattachment_create_without_preload_content(
        self,
        image_id: Annotated[str, Field(min_length=36, strict=True, max_length=36, description="The image identifier")],
        extension_id: Annotated[str, Field(min_length=1, strict=True, max_length=32, description="The extension identifier")],
        mime_type: Annotated[str, Field(min_length=1, strict=True, max_length=32, description="The MIME type of the attachment payload")],
        body: Annotated[Union[Annotated[bytes, Field(strict=True, max_length=1048576)], Annotated[str, Field(strict=True, max_length=1048576)], Tuple[str, Annotated[bytes, Field(strict=True, max_length=1048576)]]], Field(description="The attachment payload")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Declares an image binary attachment

        Stores a binary attachment related to an image for a given extension.

        :param image_id: The image identifier (required)
        :type image_id: str
        :param extension_id: The extension identifier (required)
        :type extension_id: str
        :param mime_type: The MIME type of the attachment payload (required)
        :type mime_type: str
        :param body: The attachment payload (required)
        :type body: bytearray
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._imageattachment_create_serialize(
            image_id=image_id,
            extension_id=extension_id,
            mime_type=mime_type,
            body=body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "str",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _imageattachment_create_serialize(
        self,
        image_id,
        extension_id,
        mime_type,
        body,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if image_id is not None:
            
            _query_params.append(('imageId', image_id))
            
        if extension_id is not None:
            
            _query_params.append(('extensionId', extension_id))
            
        if mime_type is not None:
            
            _query_params.append(('mimeType', mime_type))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if body is not None:
            # convert to byte array if the input is a file name (str)
            if isinstance(body, str):
                with open(body, "rb") as _fp:
                    _body_params = _fp.read()
            elif isinstance(body, tuple):
                # drop the filename from the tuple
                _body_params = body[1]
            else:
                _body_params = body


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'image/png', 
                        'image/jpeg', 
                        'image/webp', 
                        'image/gif', 
                        'image/avif', 
                        'image/heif', 
                        'application/octet-stream'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'api-key'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/imageAttachment/create',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def imageattachment_download(
        self,
        uri: Annotated[str, Field(min_length=8, strict=True, max_length=4096, description="The attachment URI")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> bytearray:
        """Downloads an image binary attachment

        Retrieves the payload of a binary attachment related to an image for a given extension.

        :param uri: The attachment URI (required)
        :type uri: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._imageattachment_download_serialize(
            uri=uri,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "bytearray",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def imageattachment_download_with_http_info(
        self,
        uri: Annotated[str, Field(min_length=8, strict=True, max_length=4096, description="The attachment URI")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[bytearray]:
        """Downloads an image binary attachment

        Retrieves the payload of a binary attachment related to an image for a given extension.

        :param uri: The attachment URI (required)
        :type uri: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._imageattachment_download_serialize(
            uri=uri,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "bytearray",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def imageattachment_download_without_preload_content(
        self,
        uri: Annotated[str, Field(min_length=8, strict=True, max_length=4096, description="The attachment URI")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Downloads an image binary attachment

        Retrieves the payload of a binary attachment related to an image for a given extension.

        :param uri: The attachment URI (required)
        :type uri: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._imageattachment_download_serialize(
            uri=uri,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "bytearray",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _imageattachment_download_serialize(
        self,
        uri,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if uri is not None:
            _path_params['uri'] = uri
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/octet-stream', 
                    'image/png', 
                    'image/jpeg', 
                    'image/webp', 
                    'image/gif', 
                    'image/avif', 
                    'image/heif'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'api-key'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/imageAttachment/{uri}/download',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )


